@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-from collections import Iterable
+from collections.abc import Iterable
 
 class XML:
     def __init__(self, text_xml, version, character, background, shapes, joints, special_items, triggers, groups):
